%bcond_with doc_subpackage

Summary:       Provide components to build one-time password authentication systems
Name:          oath-toolkit
Version:       2.6.7
Release:       9%{?dist}
License:       GPLv3+
URL:           https://www.nongnu.org/oath-toolkit/
Source0:       https://download.savannah.nongnu.org/releases/%{name}/%{name}-%{version}.tar.gz

Patch3000:     oath-toolkit-2.6.7-lockfile.patch
Patch3001:     fix-cve-2024-47191.patch

BuildRequires: make libtool libtool-ltdl-devel
BuildRequires: pam-devel xmlsec1-devel xmlsec1-openssl-devel
%if 0%{with doc_subpackage}
BuildRequires: gtk-doc
%endif


%description
The OATH Toolkit provide components for building one-time password
authentication systems. It contains shared libraries, command line tools and a
PAM module. Supported technologies include the event-based HOTP algorithm
(RFC4226) and the time-based TOTP algorithm (RFC6238). OATH stands for Open
AuTHentication, which is the organization that specify the algorithms. For
managing secret key files, the Portable Symmetric Key Container (PSKC) format
described in RFC6030 is supported.


%package -n liboath
Summary:       Library for OATH handling
License:       LGPLv2+
Provides:      bundled(gnulib)

%description -n liboath
OATH stands for Open AuTHentication, which is the organization that
specify the algorithms. Supported technologies include the event-based
HOTP algorithm (RFC4226) and the time-based TOTP algorithm (RFC6238).

%package -n liboath-devel
Summary:       Development files for liboath
License:       LGPLv2+
Requires:      liboath = %{version}-%{release}

%description -n liboath-devel
Development files for liboath.

%if 0%{with doc_subpackage}
%package -n liboath-doc
Summary:       Documentation files for liboath
License:       LGPLv2+
Requires:      liboath = %{version}-%{release}
Requires:      gtk-doc
BuildArch:     noarch

%description -n liboath-doc
Documentation files for liboath.
%endif

%package -n libpskc
Summary:       Library for PSKC handling
License:       LGPLv2+
Requires:      xml-common
Provides:      bundled(gnulib)

%description -n libpskc
Library for managing secret key files, the Portable Symmetric Key
Container (PSKC) format described in RFC6030 is supported.

%package -n libpskc-devel
Summary:       Development files for libpskc
License:       LGPLv2+
Requires:      libpskc = %{version}-%{release}

%description -n libpskc-devel
Development files for libpskc.

%if 0%{with doc_subpackage}
%package -n libpskc-doc
Summary:       Documentation files for libpskc
License:       LGPLv2+
Requires:      libpskc = %{version}-%{release}
Requires:      gtk-doc
BuildArch:     noarch

%description -n libpskc-doc
Documentation files for libpskc.
%endif

%package -n oathtool
Summary:       A command line tool for generating and validating OTPs
License:       GPLv3+
Provides:      bundled(gnulib)

%description -n oathtool
A command line tool for generating and validating OTPs.

%package -n pskctool
Summary:       A command line tool for manipulating PSKC data
Provides:      bundled(gnulib)
Requires:      xmlsec1-openssl

%description -n pskctool
A command line tool for manipulating PSKC data.

%package -n pam_oath
Summary:       A PAM module for pluggable login authentication for OATH
Requires:      pam

%description -n pam_oath
A PAM module for pluggable login authentication for OATH.


%prep
%autosetup -p1


%build
%if 0%{without doc_subpackage}
export GTKDOCIZE=true
%endif
autoreconf -fi
%configure --with-pam-dir=%{_libdir}/security

for d in liboath libpskc pskctool oathtool pam_oath
do
  sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' $d/libtool
  sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' $d/libtool
  sed -i 's| -shared | -Wl,--as-needed\0|g' $d/libtool
done
%make_build


%install
%make_install
rm -f %{buildroot}%{_libdir}/*.{a,la}
rm -f %{buildroot}%{_libdir}/security/*.la
mkdir -p -m 0600 %{buildroot}%{_sysconfdir}/liboath
%if 0%{without doc_subpackage}
rm -rf %{buildroot}%{_datadir}/gtk-doc/html/
rm -rf %{buildroot}%{_mandir}/man3/
%endif


%files -n liboath
%license liboath/COPYING
%attr(0600, root, root) %dir %{_sysconfdir}/liboath
%{_libdir}/liboath.so.*

%files -n liboath-devel
%{_includedir}/liboath
%{_libdir}/liboath.so
%{_libdir}/pkgconfig/liboath.pc

%if 0%{with doc_subpackage}
%files -n liboath-doc
%{_mandir}/man3/oath*
%{_datadir}/gtk-doc/html/liboath/*
%endif

%files -n libpskc
%doc libpskc/README
%{_libdir}/libpskc.so.*
%{_datadir}/xml/pskc

%files -n libpskc-devel
%{_includedir}/pskc
%{_libdir}/libpskc.so
%{_libdir}/pkgconfig/libpskc.pc

%if 0%{with doc_subpackage}
%files -n libpskc-doc
%{_mandir}/man3/pskc*
%{_datadir}/gtk-doc/html/libpskc/*
%endif

%files -n oathtool
%doc oathtool/COPYING
%{_bindir}/oathtool
%{_mandir}/man1/oathtool.*

%files -n pskctool
%{_bindir}/pskctool
%{_mandir}/man1/pskctool.*

%files -n pam_oath
%doc pam_oath/README pam_oath/COPYING
%{_libdir}/security/pam_oath.so


%changelog
* Sun Oct 20 2024 Tao Wu <tallwu@tencent.com> - 2.6.7-9
- [Type] security
- [Desc] Fix cve-2024-47191

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.6.7-8
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.6.7-7
- Rebuilt for loongarch release

* Mon Oct 30 2023 Miaojun Dong <zoedong@tencent.com> - 2.6.7-6
- Update the summary and fix typo

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.6.7-5
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Aug 18 2023 Wang Guodong <gordonwwang@tencent.com> - 2.6.7-4
- Rebuilt for xmlsec1 1.2.38

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.6.7-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.6.7-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Dec 16 2022 Miaojun Dong <zoedong@tencent.com> - 2.6.7-1
- initial build
